congruence: Calculate congruence score between pairs of of genes sharing...

Description Usage Arguments Value Author(s) References See Also Examples

View source: R/congruence-methods.R

Description

The congruence score represents the number of common synthetic genetic interacting partners between two genes. The higher is the score the more overlap there is between the synthetic genetic partners of those genes.

Usage

1
congruence(iMat, sharedInt, mode="query", universe, padjust=FALSE)

Arguments

iMat

Adjacency matrix reporting genetic Interactions. Each entry has value 0 or 1, representing positive or negative interaction of corresponding pairs of row and column, respectively.

sharedInt

numeric vector representing the number of common genetic interactions between a pair of query or target genes. See getSharedInteraction for more details

mode

character vector of value "query" or "target"

universe

total number of genes tested

padjust

adjust by the number of genes tested that show at least one synthetic genetic interaction.

Value

A numeric vector of the congruence score values.

Author(s)

N. LeMeur

References

Ye P. et al. (2005). Gene function prediction from congruent synthetic lethal interactions in yeast. Molecular Systems Biology 1:2005.0026.

See Also

getSharedInteraction

Examples

1
2
3
4
5
6
intM <- matrix(c(0,1,0,0,1,1,1,0,1,1,1,1,1,0,1,1),
                nrow=4, ncol=4, 
                dimnames=list(c("p1","p2","p3","p4"),
                  c("p1","p3","p5","p7")))
sharedInt <- getSharedInteraction(intM)
score <- congruence(intM, sharedInt, mode="query", universe=15, padjust=FALSE)

Example output

Loading required package: ScISI
Loading required package: GO.db
Loading required package: AnnotationDbi
Loading required package: stats4
Loading required package: BiocGenerics
Loading required package: parallel

Attaching package: ‘BiocGenerics’

The following objects are masked from ‘package:parallel’:

    clusterApply, clusterApplyLB, clusterCall, clusterEvalQ,
    clusterExport, clusterMap, parApply, parCapply, parLapply,
    parLapplyLB, parRapply, parSapply, parSapplyLB

The following objects are masked from ‘package:stats’:

    IQR, mad, sd, var, xtabs

The following objects are masked from ‘package:base’:

    anyDuplicated, append, as.data.frame, basename, cbind, colnames,
    dirname, do.call, duplicated, eval, evalq, Filter, Find, get, grep,
    grepl, intersect, is.unsorted, lapply, Map, mapply, match, mget,
    order, paste, pmax, pmax.int, pmin, pmin.int, Position, rank,
    rbind, Reduce, rownames, sapply, setdiff, sort, table, tapply,
    union, unique, unsplit, which.max, which.min

Loading required package: Biobase
Welcome to Bioconductor

    Vignettes contain introductory material; view with
    'browseVignettes()'. To cite Bioconductor, see
    'citation("Biobase")', and for packages 'citation("pkgname")'.

Loading required package: IRanges
Loading required package: S4Vectors

Attaching package: ‘S4Vectors’

The following object is masked from ‘package:base’:

    expand.grid


Loading required package: RpsiXML
Loading required package: annotate
Loading required package: XML
Loading required package: graph

Attaching package: ‘graph’

The following object is masked from ‘package:XML’:

    addNode

Loading required package: RBGL
Loading required package: hypergraph
No methods found in package ‘Biobase’ for request: ‘listlen’ when loading ‘RpsiXML’
No methods found in package ‘annotate’ for requests: ‘pubmed’, ‘buildPubMedAbst’ when loading ‘RpsiXML’

Attaching package: ‘RpsiXML’

The following object is masked from ‘package:IRanges’:

    members

Loading required package: apComplex

Loading required package: lattice
No methods found in package ‘BiocGenerics’ for request: ‘plot’ when loading ‘SLGI’

SLGI documentation built on Nov. 8, 2020, 11 p.m.